import { ScanOptions } from './interfaces/ITScanOptions';
/**
 * Escanea los datos de un objeto FormData en busca de posibles problemas de seguridad.
 *
 * @param formData - El objeto FormData que se va a escanear.
 * @param options - Opciones de escaneo.
 * @returns Un array de strings que contiene los problemas encontrados durante el escaneo.
 *
 * @remarks
 * Esta función recorre los datos de un objeto FormData y realiza un escaneo en busca de posibles problemas de seguridad.
 * Los problemas encontrados se agregan a un array y se devuelven al finalizar el escaneo.
 *
 * @example
 * ```typescript
 * const formData = new FormData();
 * formData.append('username', 'admin');
 * formData.append('password', '123456');
 *
 * const options = {
 *   keys: true,
 *   values: true
 * };
 *
 * const issues = scanFormData(formData, options);
 * console.log(issues); ['Possible SQL injection detected in key: username']
 * ```
 *
 * @author Andres Gutierrez Velez
 * @since 21/06/2024
 * @contact sr.willardkraft@gmail.com
 */
export declare function scanFormData(formData: FormData, options: ScanOptions): string[];
